==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-directorymenu/translations/directorymenu_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="120"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>目录菜单设置</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>起始目录:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>基本目录名</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>图标:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="91"/>
        <source>Choose Base Directory</source>
        <translation>选择起始目录</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="107"/>
        <source>Choose Icon</source>
        <translation>选择图标</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="107"/>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>图标 (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="116"/>
        <source>Directory Menu</source>
        <translation>目录菜单</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="116"/>
        <source>An error occurred while loading the icon.</source>
        <translation>加载图标时出现错误。</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-directorymenu/translations/directorymenu_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="125"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../directorymenu.cpp" line="129"/>
        <source>Open in terminal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>目录菜单设置</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>起始目录:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>基本目录名</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>图标:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="66"/>
        <source>Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="73"/>
        <location filename="../directorymenuconfiguration.cpp" line="112"/>
        <source>Choose Default Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="96"/>
        <source>Choose Base Directory</source>
        <translation>选择起始目录</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="126"/>
        <source>Choose Icon</source>
        <translation>选择图标</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="126"/>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>图标 (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="135"/>
        <source>Directory Menu</source>
        <translation>目录菜单</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="135"/>
        <source>An error occurred while loading the icon.</source>
        <translation>加载图标时出现错误。</translation>
    </message>
</context>
</TS>
